==> apache-tomcat-9.0.20-src.tar.gz: apache-tomcat-9.0.20-src/java/org/apache/tomcat/util/scan/NonClosingJarInputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.scan;

import java.io.IOException;
import java.io.InputStream;
import java.util.jar.JarInputStream;

/**
 * When using a {@link JarInputStream} with an XML parser, the stream will be
 * closed by the parser. This causes problems if multiple entries from the JAR
 * need to be parsed. This implementation makes {{@link #close()} a NO-OP and
 * adds {@link #reallyClose()} that will close the stream.
 */
public class NonClosingJarInputStream extends JarInputStream {

    public NonClosingJarInputStream(InputStream in, boolean verify)
            throws IOException {
        super(in, verify);
    }

    public NonClosingJarInputStream(InputStream in) throws IOException {
        super(in);
    }

    @Override
    public void close() throws IOException {
        // Make this a NO-OP so that further entries can be read from the stream
    }

    public void reallyClose() throws IOException {
        super.close();
    }
}

==> apache-tomcat-9.0.107-src.tar.gz: apache-tomcat-9.0.107-src/java/org/apache/tomcat/util/scan/NonClosingJarInputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.scan;

import java.io.IOException;
import java.io.InputStream;
import java.util.jar.JarInputStream;

/**
 * When using a {@link JarInputStream} with an XML parser, the stream will be closed by the parser. This causes problems
 * if multiple entries from the JAR need to be parsed. This implementation makes {{@link #close()} a NO-OP and adds
 * {@link #reallyClose()} that will close the stream.
 */
public class NonClosingJarInputStream extends JarInputStream {

    public NonClosingJarInputStream(InputStream in, boolean verify) throws IOException {
        super(in, verify);
    }

    public NonClosingJarInputStream(InputStream in) throws IOException {
        super(in);
    }

    @Override
    public void close() throws IOException {
        // Make this a NO-OP so that further entries can be read from the stream
    }

    public void reallyClose() throws IOException {
        super.close();
    }
}
